@@ -93,6 +93,8 @@ Dialog::Dialog(int viewId, QWidget *parent) :
         QString dir = imageSets.at(i);
         imageSetNames.append(dir);
     }
+    imageSets.removeAll(".");
+    imageSets.removeAll("..");
     ui->imageSetComboBox->addItems(imageSetNames);
 
     /*
